to_timestamp

Function to_timestamp 

pub fn to_timestamp(
    column: &Column,
    format: Option<&str>,
) -> Result<Column, String>
Cast to timestamp, or parse with format when provided (PySpark to_timestamp). When format is None, parses string columns with default format ā€œ%Y-%m-%d %H:%M:%Sā€ (PySpark parity #273).